==> elisa-plugins-bad_0.5.9-1.orig.tar.gz: elisa-plugins-bad-0.5.9/elisa/plugins/wmd/tests/test_wmd_resource.py <==
# -*- coding: utf-8 -*-
# Elisa - Home multimedia server
# Copyright (C) 2006-2008 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.

"""
Test the wmd Resource provider
"""

from twisted.trial.unittest import TestCase, SkipTest
from twisted.internet import defer

from elisa.core import common
from elisa.core.media_uri import MediaUri
from elisa.plugins.wmd.wmd_resource import WMDResource
from elisa.plugins.wmd.models import VolumesModel, VolumeModel

class WMDMixin(object):
    """
    Base class that sets up the resource provider and patches the application
    and the bus
    """

    def setUp(self):
        self.supported_protocols = ('file', 'cdda', 'ipod')

        def created(resource):
            self.resource = resource

        # patch the application:
        class Dummy(object):pass

        class DummyBus(object):
            def __init__(self):
                self.messages = []
            def register(*args):
                pass
            def send_message(self, msg, sender):
                self.messages.append( msg )

        self.bus = DummyBus()

        self.app = common.application
        common.application = Dummy()
        common.application.bus = self.bus

        return WMDResource.create({}).addCallback(created)

    def tearDown(self):
        common.application = self.app

class TestVolumeParsing(WMDMixin, TestCase):
    """
    Test the volume recognition system.

    These tests contain also print statements to display the detected devices because it is not
    predictable which hardware setup the test computer has.
    """

    def test_unfiltered(self):
        """
        test if all devices are found
        """
        # XXX: plug a usb hard disk in the test machine and see if it is displayed
        uri = MediaUri("volumes://localhost")
        model, dfr = self.resource.get(uri, None)
        self.assertTrue(isinstance(model, VolumesModel))
        for m in model.volumes:
            self.assertTrue(m.protocol in self.supported_protocols)
            self.assertEqual(len(m.mount_point), 1)
            self.assertNotEqual(m.label, "")
            print "Found volume '%s' in '%s:' with protocol '%s'." % \
                                    (m.label, m.mount_point, m.protocol)

    def test_filtered(self):
        """
        test to find all devices with cdda
        """
        uri = MediaUri("volumes://localhost/?filter=cdda")
        model, dfr = self.resource.get(uri, None)
        self.assertTrue(isinstance(model, VolumesModel))
        for m in model.volumes:
            self.assertTrue(m.protocol in self.supported_protocols)
            self.assertEqual(len(m.mount_point), 1)
            self.assertNotEqual(m.label, "")
            print "Found volume '%s' in '%s:' with protocol '%s'." % \
                                    (m.label, m.mount_point, m.protocol)

    def test_get_drive_info(self):
        """
        test if info request for a specific drive is done correctly
        and right model is returned
        """
        # XXX: setup test machine that there is something in the drive
        udi = 'L'
        model = self.resource._get_attached_volumes(drive_letter=udi)
        if model:
            self.assertTrue(isinstance(model, VolumeModel))
            self.assertTrue(model.protocol in self.supported_protocols)
            self.assertEqual(len(model.mount_point), 1)
            self.assertNotEqual(model.label, "")
            print "Found volume '%s' in '%s:' with protocol '%s'." % \
                        (model.label, model.mount_point, model.protocol)

==> elisa-plugins-bad_0.5.15.5.orig.tar.gz: elisa-plugins-bad-0.5.15.5/elisa/plugins/wmd/tests/test_wmd_resource.py <==
# -*- coding: utf-8 -*-
# Elisa - Home multimedia server
# Copyright (C) 2006-2008 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.

"""
Test the wmd Resource provider
"""

from twisted.trial.unittest import TestCase, SkipTest
from twisted.internet import defer

from elisa.core import common
from elisa.core.media_uri import MediaUri
from elisa.plugins.wmd.wmd_resource import WMDResource
from elisa.plugins.base.models.device import VolumeModel, DevicesModel

class WMDMixin(object):
    """
    Base class that sets up the resource provider and patches the application
    and the bus
    """

    def setUp(self):
        self.supported_protocols = ('file', 'cdda', 'ipod')

        def created(resource):
            self.resource = resource

        # patch the application:
        class Dummy(object):pass

        class DummyBus(object):
            def __init__(self):
                self.messages = []
            def register(*args):
                pass
            def send_message(self, msg, sender):
                self.messages.append( msg )

        self.bus = DummyBus()

        self.app = common.application
        common.application = Dummy()
        common.application.bus = self.bus

        return WMDResource.create({}).addCallback(created)

    def tearDown(self):
        common.application = self.app
        return self.resource.clean()

class TestVolumeParsing(WMDMixin, TestCase):
    """
    Test the volume recognition system.

    These tests contain also print statements to display the detected devices because it is not
    predictable which hardware setup the test computer has.
    """

    def test_unfiltered(self):
        """
        test if all devices are found
        """
        # XXX: plug a usb hard disk in the test machine and see if it is displayed
        uri = MediaUri("volumes://localhost")
        model, dfr = self.resource.get(uri, None)
        self.assertTrue(isinstance(model, DevicesModel))
        for m in model.devices:
            self.assertTrue(m.protocol in self.supported_protocols)
            self.assertEqual(len(m.mount_point), 1)
            self.assertNotEqual(m.label, "")
            print "Found volume '%s' in '%s:' with protocol '%s'." % \
                                    (m.label, m.mount_point, m.protocol)

    def test_filtered(self):
        """
        test to find all devices with cdda
        """
        uri = MediaUri("volumes://localhost/?filter=cdda")
        model, dfr = self.resource.get(uri, None)
        self.assertTrue(isinstance(model, DevicesModel))
        for m in model.devices:
            self.assertTrue(m.protocol in self.supported_protocols)
            self.assertEqual(len(m.mount_point), 1)
            self.assertNotEqual(m.label, "")
            print "Found volume '%s' in '%s:' with protocol '%s'." % \
                                    (m.label, m.mount_point, m.protocol)
